@@ -5,6 +5,7 @@ from urllib.parse import urlparse
 
 from oelint_parser.cls_item import Variable
 from oelint_parser.constants import CONSTANTS
+from oelint_parser.rpl_regex import RegexRpl
 
 
 def get_files(stash, _file, pattern):
@@ -18,17 +19,18 @@ def get_files(stash, _file, pattern):
     Returns:
         list -- list of files matching pattern
     """
-    res = []
+    res = set()
     src_uris = stash.GetItemsFor(filename=_file, classifier=Variable.CLASSIFIER,
                                  attribute=Variable.ATTR_VAR, attributeValue="SRC_URI")
-    files_paths = list(
-        set(["{}/*/{}".format(os.path.dirname(x.Origin), pattern) for x in src_uris]))
+    files_paths = {
+        "{dir}/*/{pattern}".format(dir=os.path.dirname(x.Origin), pattern=pattern) for x in src_uris}
     for item in src_uris:
-        files_paths += list(set(["{}/*/{}".format(os.path.dirname(x.Origin), pattern)
-                                 for x in stash.GetItemsFor(filename=item.Origin)]))
+        files_paths.update({"{dir}/*/{pattern}".format(dir=os.path.dirname(x.Origin), pattern=pattern)
+                           for x in stash.GetItemsFor(filename=item.Origin)})
     for item in files_paths:
-        res += glob.glob(item)
-    return list(set(res))
+        res.update(glob.glob(item))
+    return sorted(res)
+
 
 def get_layer_root(name):
     """Find the path to the layer root of a file
@@ -100,12 +102,13 @@ def get_scr_components(string):
         _tmp += "/" + _url.path.lstrip("/")
     _path = _tmp.split(";")[0]
     _options = _raw.split(";")[1:] if ";" in _raw else []
-    _parsed_opt = {x.split("=")[0]: x.split("=")[1] for x in _options if "=" in x}
+    _parsed_opt = {x.split("=")[0]: x.split("=")[1]
+                   for x in _options if "=" in x}
     return {"scheme": _scheme, "src": _path, "options": _parsed_opt}
 
 
 def safe_linesplit(string):
-    """Split line in a safe manner 
+    """Split line in a safe manner
 
     Arguments:
         string {str} -- raw input
@@ -113,7 +116,8 @@ def safe_linesplit(string):
     Returns:
         list -- safely split input
     """
-    return re.split(r"\s|\t|\x1b", string)
+    return RegexRpl.split(r"\s|\t|\x1b", string)
+
 
 def guess_recipe_name(_file):
     """Get the recipe name from filename
@@ -127,8 +131,9 @@ def guess_recipe_name(_file):
     _name, _ = os.path.splitext(os.path.basename(_file))
     return _name.split("_")[0]
 
+
 def guess_base_recipe_name(_file):
-    """Get the base recipe name from filename
+    """Get the base recipe name from filename (aka BPN)
 
     Arguments:
         _file {str} -- filename
@@ -136,10 +141,11 @@ def guess_base_recipe_name(_file):
     Returns:
         str -- recipe name
     """
-    _name = guess_recipe_name(_file)
-    for x in ["-native", "-nativesdk", "-cross"]:
-        _name = ''.join(_name.rsplit(x, 1))
-    return _name
+    tmp_ = re.sub(r"^(nativesdk-)*(.+)(-native)*(-cross)*", r"\2", guess_recipe_name(_file))
+    tmp_ = re.sub(r"^(.+)(-native)$", r"\1", tmp_)
+    tmp_ = re.sub(r"^(.+)(-cross)$", r"\1", tmp_)
+    return tmp_
+
 
 def guess_recipe_version(_file):
     """Get recipe version from filename
@@ -153,7 +159,8 @@ def guess_recipe_version(_file):
     _name, _ = os.path.splitext(os.path.basename(_file))
     return _name.split("_")[-1]
 
-def expand_term(stash, _file, value, spare=[], seen={}):
+
+def expand_term(stash, _file, value, spare=None, seen=None):
     """Expand a variable (replacing all variables by known content)
 
     Arguments:
@@ -164,32 +171,48 @@ def expand_term(stash, _file, value, spare=[], seen={}):
     Returns:
         str -- expanded value
     """
+    baseset = CONSTANTS.SetsBase
     pattern = r"\$\{(.+?)\}"
+    seen = seen or {}
+    spare = spare or []
     res = str(value)
-    for m in re.finditer(pattern, value):
+    for m in RegexRpl.finditer(pattern, value):
         if m.group(1) in spare:
             continue
         _comp = [x for x in stash.GetItemsFor(filename=_file, classifier=Variable.CLASSIFIER,
-                        attribute=Variable.ATTR_VAR, attributeValue=m.group(1)) if not x.AppendOperation()]
+                                              attribute=Variable.ATTR_VAR, attributeValue=m.group(1)) if not x.AppendOperation()]
 
         if any(_comp):
             if m.group(1) in seen.keys():
                 _rpl = seen[m.group(1)]
             else:
                 seen[m.group(1)] = ""
-                _rpl = expand_term(stash, _file, _comp[0].VarValueStripped, seen=seen)
+                _rpl = expand_term(
+                    stash, _file, _comp[0].VarValueStripped, seen=seen)
                 seen[m.group(1)] = _rpl
             res = res.replace(m.group(0), _rpl)
+        elif m.group(1) in baseset:
+            if m.group(1) in seen.keys():
+                _rpl = seen[m.group(1)]
+            elif m.group(1) in baseset:
+                seen[m.group(1)] = ""
+                _rpl = expand_term(
+                    stash, _file, baseset[m.group(1)], seen=seen)
+                seen[m.group(1)] = _rpl
+            else:
+                _rpl = m.group(1)
+            res = res.replace(m.group(0), _rpl)
         elif m.group(1) in ["PN"]:
             res = res.replace(m.group(0), guess_recipe_name(_file))
         elif m.group(1) in ["BPN"]:
-            res = res.replace(m.group(0), ''.join(guess_recipe_name(_file).rsplit('-native', 1)))
+            res = res.replace(m.group(0), guess_base_recipe_name(_file))
         elif m.group(1) in ["PV"]:
             res = res.replace(m.group(0), guess_recipe_version(_file))
         elif not any(_comp):
             continue
     return res
 
+
 def get_valid_package_names(stash, _file, strippn=False):
     """Get known valid names for packages
 
@@ -204,11 +227,12 @@ def get_valid_package_names(stash, _file, strippn=False):
     _comp = stash.GetItemsFor(filename=_file, classifier=Variable.CLASSIFIER,
                               attribute=Variable.ATTR_VAR, attributeValue="PACKAGES")
     _comp += stash.GetItemsFor(filename=_file, classifier=Variable.CLASSIFIER,
-                              attribute=Variable.ATTR_VAR, attributeValue="PACKAGE_BEFORE_PN")
+                               attribute=Variable.ATTR_VAR, attributeValue="PACKAGE_BEFORE_PN")
     _recipe_name = guess_recipe_name(_file)
     res.add(_recipe_name)
-    res.add("{}-ptest".format(_recipe_name))
-    res.update(["{}-{}".format(_recipe_name, x) for x in ["src", "dbg", "staticdev", "dev", "doc", "locale"]])
+    res.add("{recipe}-ptest".format(recipe=_recipe_name))
+    res.update(["{recipe}-{pkg}".format(recipe=_recipe_name, pkg=x)
+               for x in ["src", "dbg", "staticdev", "dev", "doc", "locale"]])
     for item in _comp:
         for pkg in [x for x in safe_linesplit(expand_term(stash, _file, item.VarValueStripped, spare=["PN"])) if x]:
             if not strippn:
@@ -218,6 +242,7 @@ def get_valid_package_names(stash, _file, strippn=False):
             res.add(_pkg)
     return res
 
+
 def get_valid_named_resources(stash, _file):
     """Get list of valid SRCREV resource names
 
@@ -240,6 +265,7 @@ def get_valid_named_resources(stash, _file):
                 res.add(_url["options"]["name"].replace("${PN}", _recipe_name))
     return res
 
+
 def is_image(stash, _file):
     """returns if the file is likely an image recipe or not
 
@@ -253,15 +279,17 @@ def is_image(stash, _file):
     res = False
 
     _inherits = stash.GetItemsFor(filename=_file, classifier=Variable.CLASSIFIER,
-                              attribute=Variable.ATTR_VAR, attributeValue="inherit")
-    res |= any(x for x in _inherits if x.VarValueStripped in CONSTANTS.ImagesClasses)
+                                  attribute=Variable.ATTR_VAR, attributeValue="inherit")
+    res |= any(
+        x for x in _inherits if x.VarValueStripped in CONSTANTS.ImagesClasses)
 
     for _var in CONSTANTS.ImagesVariables:
         res |= any(stash.GetItemsFor(filename=_file, classifier=Variable.CLASSIFIER,
-                              attribute=Variable.ATTR_VAR, attributeValue=_var))
+                                     attribute=Variable.ATTR_VAR, attributeValue=_var))
 
     return res
 
+
 def is_packagegroup(stash, _file):
     """returns if the file is likely a packagegroup recipe or not
 
@@ -272,8 +300,6 @@ def is_packagegroup(stash, _file):
     Returns:
         bool -- True if _file is a packagegroup recipe
     """
-    res = False
-
     _inherits = stash.GetItemsFor(filename=_file, classifier=Variable.CLASSIFIER,
-                              attribute=Variable.ATTR_VAR, attributeValue="inherit")
+                                  attribute=Variable.ATTR_VAR, attributeValue="inherit")
     return any(x for x in _inherits if x.VarValueStripped in ["packagegroup"])
